@@ -15,8 +15,7 @@ DBIx::Class::Schema::Loader::DBI::SQLite - DBIx::Class::Schema::Loader SQLite Im
   package My::Schema;
   use base qw/DBIx::Class::Schema::Loader/;
 
-  __PACKAGE__->connection("dbi:SQLite:dbname=/path/to/dbfile");
-  __PACKAGE__->load_from_connection( relationships => 1 );
+  __PACKAGE__->loader_optoins( relationships => 1 );
 
   1;
 
@@ -153,7 +152,8 @@ sub _tables_list {
 
 =head1 SEE ALSO
 
-L<DBIx::Schema::Class::Loader>
+L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
+L<DBIx::Class::Schema::Loader::DBI>
 
 =cut
 
